pari_jupyter: Jupyter kernel for PARI/GP
========================================

Description
-----------

Jupyter kernel for PARI/GP

License
-------

GPL version 3 or later


Upstream Contact
----------------

-  https://github.com/sagemath/pari-jupyter

Dependencies
------------

-  Python >= 3.6.1
-  Jupyter 4
-  PARI version 2.13 or later
-  Readline (any version which works with PARI)
-  Optional: Cython version 0.25 or later
